@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,19 +16,17 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Variance generators in real and reciprocal space for fluctuation electron
-microscopy.
-
-"""
+"""Variance generators in real and reciprocal space for fluctuation electron microscopy."""
 
 import numpy as np
 from hyperspy.signals import Signal2D
 from hyperspy.api import stack
 
-from pyxem.signals.diffraction_variance2d import DiffractionVariance2D
-from pyxem.signals.diffraction_variance2d import ImageVariance
-from pyxem.signals import transfer_signal_axes
-from pyxem.signals import transfer_navigation_axes_to_signal_axes
+from pyxem.signals import DiffractionVariance2D, ImageVariance
+from pyxem.utils.signal import (
+    transfer_navigation_axes_to_signal_axes,
+    transfer_signal_axes,
+)
 
 
 class VarianceGenerator:
@@ -44,6 +42,7 @@ class VarianceGenerator:
 
     def __init__(self, signal, *args, **kwargs):
         self.signal = signal
+        self.thickness_filter = None
 
         # add a check for calibration
 
@@ -106,14 +105,12 @@ class VarianceGenerator:
 
         Parameters
         ----------
-
         dqe : float
             Detective quantum efficiency of the detector for Poisson noise
             correction.
 
         Returns
         -------
-
         varims : ImageVariance
             A two dimensional Signal class object containing the mean DP, mean
             squared DP, and variance DP, and a Poisson noise-corrected variance
