@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,8 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Signals to be operated on. The basic unit of data"""
+
 from .common_diffraction import CommonDiffraction
 from .correlation2d import Correlation2D, LazyCorrelation2D
+from .beam_shift import BeamShift, LazyBeamShift
 from .differential_phase_contrast import (
     DPCBaseSignal,
     DPCSignal1D,
@@ -33,13 +36,14 @@ from .diffraction1d import Diffraction1D, LazyDiffraction1D
 from .diffraction2d import Diffraction2D, LazyDiffraction2D
 from .electron_diffraction1d import ElectronDiffraction1D, LazyElectronDiffraction1D
 from .electron_diffraction2d import ElectronDiffraction2D, LazyElectronDiffraction2D
-from .indexation_results import TemplateMatchingResults, VectorMatchingResults
+from .indexation_results import VectorMatchingResults
 from .pair_distribution_function1d import PairDistributionFunction1D
 from .polar_diffraction2d import PolarDiffraction2D, LazyPolarDiffraction2D
 from .power2d import Power2D, LazyPower2D
 from .reduced_intensity1d import ReducedIntensity1D
 from .segments import LearningSegment, VDFSegment
 from .strain_map import StrainMap
+from .correlation1d import Correlation1D
 from .tensor_field import DisplacementGradientMap
 from .virtual_dark_field_image import VirtualDarkFieldImage
 
@@ -48,6 +52,8 @@ __all__ = [
     "CommonDiffraction",
     "Correlation2D",
     "LazyCorrelation2D",
+    "BeamShift",
+    "LazyBeamShift",
     "DPCBaseSignal",
     "DPCSignal1D",
     "DPCSignal2D",
@@ -78,6 +84,7 @@ __all__ = [
     "LearningSegment",
     "VDFSegment",
     "StrainMap",
+    "Correlation1D",
     "DisplacementGradientMap",
     "VirtualDarkFieldImage",
 ]
