@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -15,21 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
-"""
-Signal class for two-dimensional electron diffraction data in Cartesian
-coordinates.
-"""
+
 
 import numpy as np
-from hyperspy.signals import BaseSignal
-from hyperspy._signals.lazy import LazySignal
 
-from pyxem.signals.diffraction2d import Diffraction2D
-from pyxem.signals.electron_diffraction1d import ElectronDiffraction1D
+from pyxem.signals.diffraction2d import Diffraction2D, LazyDiffraction2D
 from diffsims.utils.sim_utils import get_electron_wavelength
 
 
 class ElectronDiffraction2D(Diffraction2D):
+    """
+    Signal class for two-dimensional electron diffraction data in Cartesian
+    coordinates.
+    """
     _signal_type = "electron_diffraction"
 
     def __init__(self, *args, **kwargs):
@@ -54,7 +52,24 @@ class ElectronDiffraction2D(Diffraction2D):
                     self.metadata.Acquisition_instrument.SEM,
                 )
                 del self.metadata.Acquisition_instrument.SEM
-        self.decomposition.__func__.__doc__ = BaseSignal.decomposition.__doc__
+
+    def set_ai(
+        self, center=None, energy=None, affine=None, radial_range=None, **kwargs
+    ):
+        if energy is None and self.beam_energy is not None:
+            energy = self.beam_energy
+        if energy is not None:
+            wavelength = get_electron_wavelength(energy) * 1e-10
+        else:
+            wavelength = None
+        ai = super().set_ai(
+            center=center,
+            wavelength=wavelength,
+            affine=affine,
+            radial_range=radial_range,
+            **kwargs
+        )
+        return ai
 
     @property
     def beam_energy(self):
@@ -96,30 +111,6 @@ class ElectronDiffraction2D(Diffraction2D):
         self.axes_manager.navigation_axes[0].scale = calibration
         self.axes_manager.navigation_axes[1].scale = calibration
 
-    def get_azimuthal_integral1d(self, npt_rad, beam_energy=None, **kwargs):
-        if beam_energy is None and self.beam_energy is not None:
-            beam_energy = self.beam_energy
-        if beam_energy is not None:
-            wavelength = get_electron_wavelength(self.beam_energy) * 1e-10
-        else:
-            wavelength = None
-        integration = super().get_azimuthal_integral1d(
-            npt_rad=npt_rad, wavelength=wavelength, **kwargs
-        )
-        return integration
-
-    def get_azimuthal_integral2d(self, npt_rad, beam_energy=None, **kwargs):
-        if beam_energy is None and self.beam_energy is not None:
-            beam_energy = self.beam_energy
-        if beam_energy is not None:
-            wavelength = get_electron_wavelength(self.beam_energy) * 1e-10
-        else:
-            wavelength = None
-        integration = super().get_azimuthal_integral2d(
-            npt_rad=npt_rad, wavelength=wavelength, **kwargs
-        )
-        return integration
-
     def set_experimental_parameters(
         self,
         beam_energy=None,
@@ -224,6 +215,6 @@ class ElectronDiffraction2D(Diffraction2D):
         y.units = "nm"
 
 
-class LazyElectronDiffraction2D(LazySignal, ElectronDiffraction2D):
+class LazyElectronDiffraction2D(LazyDiffraction2D, ElectronDiffraction2D):
 
     pass
