@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -27,48 +27,11 @@ from diffsims.generators.library_generator import DiffractionLibraryGenerator
 
 from pyxem.generators import TemplateIndexationGenerator
 from pyxem.signals import (
-    TemplateMatchingResults,
     VectorMatchingResults,
     DiffractionVectors,
 )
 from pyxem.utils.indexation_utils import OrientationResult
 
-
-def test_TemplateMatchingResults_to_crystal_map():
-    # multiphase
-    t = TemplateMatchingResults(np.empty((10, 10, 10, 5)))
-    t.to_crystal_map()
-    # singlephase
-    t = TemplateMatchingResults(np.ones((10, 10, 10, 5)))
-    t.to_crystal_map()
-
-
-
-def test_TemplateMatchingResults_plot_best_results_on_signal(
-    diffraction_pattern, default_structure
-):
-    """ Coverage testing """
-    edc = DiffractionGenerator(300)
-    half_side_length = 4
-    rot_list = [[0, 1, 0], [1, 0, 0]]
-
-    diff_gen = DiffractionLibraryGenerator(edc)
-    struc_lib = StructureLibrary(["A"], [default_structure], [rot_list])
-    library = diff_gen.get_diffraction_library(
-        struc_lib,
-        calibration=1 / half_side_length,
-        reciprocal_radius=0.8,
-        half_shape=(half_side_length, half_side_length),
-        with_direct_beam=True,
-    )
-    indexer = TemplateIndexationGenerator(diffraction_pattern, library)
-    match_results = indexer.correlate()
-    match_results.plot_best_matching_results_on_signal(
-        diffraction_pattern, library=library
-    )
-    plt.close("all")
-
-
 @pytest.fixture
 def sp_vector_match_result():
     # We require (total_error of row_1 > correlation row_2)
@@ -142,11 +105,11 @@ def dp_vector_match_result():
     )
     return VectorMatchingResults(res)
 
-
+@pytest.mark.skip(reason="This functionality is under limited support as of 0.14.0")
 def test_single_vector_get_crystallographic_map(sp_vector_match_result):
     _ = sp_vector_match_result.get_crystallographic_map()
 
-
+@pytest.mark.skip(reason="This functionality is under limited support as of 0.14.0")
 def test_double_vector_get_crystallographic_map(dp_vector_match_result):
     _ = dp_vector_match_result.get_crystallographic_map()
 
