@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -21,6 +21,8 @@ import math
 from functools import partial
 import numpy as np
 from skimage.measure import EllipseModel, ransac
+import warnings
+from hyperspy.signals import BaseSignal
 from hyperspy.misc.utils import isiterable
 import pyxem.utils.marker_tools as mt
 
@@ -574,3 +576,141 @@ def _get_ellipse_markers(
         marker_list.extend(marker_in_list)
         marker_list.extend(marker_out_list)
     return marker_list
+
+
+def _get_max_positions(signal, mask=None, num_points=5000):
+    """Gets the top num_points pixels in the dataset.
+
+    Parameters
+    --------------
+    signal : BaseSignal
+        The signal which we want to find the max positions for.
+    mask : np.array
+        A mask to be applied to the data for values to ignore.
+    num_points : int
+        The number of points to be considered.
+
+    """
+    if isinstance(signal, BaseSignal):
+        data = signal.data
+    else:
+        data = signal
+    i_shape = np.shape(data)
+    flattened_array = data.flatten()
+    if mask is not None:
+        flattened_mask = mask.flatten()
+        flattened_array[flattened_mask]=0
+    # take top 5000 points make sure exclude zero beam
+    indexes = np.argsort(flattened_array)
+    cords = np.array([np.floor_divide(indexes[-num_points:], i_shape[1]),
+            np.remainder(indexes[-num_points:], i_shape[1])])  # [x axis (row),y axis (col)]
+    return cords.T
+
+
+def _ellipse_to_affine(major, minor, rot):
+    if minor > major:
+        temp = minor
+        minor = major
+        major = temp
+        rot = rot + np.pi/2
+    rot = np.pi / 2 - rot
+    if rot < 0:
+        rot = rot+np.pi
+
+    Q = [[np.cos(rot), -np.sin(rot), 0],
+         [np.sin(rot), np.cos(rot), 0],
+         [0, 0, 1]]
+    S = [[1, 0, 0],
+         [0, minor / major, 0],
+         [0, 0, 1]]
+    C = np.matmul(np.matmul(Q, S), np.transpose(Q))
+    return C
+
+
+def determine_ellipse(
+    signal,
+    mask=None,
+    num_points=1000,
+    use_ransac=False,
+    guess_starting_params=True,
+    return_params=False,
+    **kwargs,
+):
+    """
+    This method starts by taking some number of points which are the most intense
+    in the signal.  It then takes those points and guesses some starting parameters
+    for the `get_ellipse_model_ransac_single_frame` function. From there it will try
+    to determine the ellipse parameters.
+
+    Parameters
+    -----------
+    signal : Signal2D
+        The signal of interest.
+    mask : Array-like
+        The mask to be applied to the data.  The True values are ignored.
+    num_points : int
+        The number of points to consider.
+    use_ransac : bool
+        If Ransac should be used to determine the ellipse. False is faster but less.
+        robust with respect to noise.
+    guess_starting_params : bool
+        If True then the starting parameters will be guessed based on the points determined.
+    return_params : bool
+        If the ellipse parameters should be returned as well.
+    **kwargs:
+        Any other keywords for `get_ellipse_model_ransac_single_frame`.
+
+    Returns
+    -------
+    center : (x,y)
+        The center of the diffraction pattern.
+    affine :
+        The affine transformation to make the diffraction pattern circular.
+
+    Examples
+    --------
+    >>> import pyxem.utils.ransac_ellipse_tools as ret
+    >>> import pyxem.dummy_data.make_diffraction_test_data as mdtd
+    >>> test_data = mdtd.MakeTestData(200, 200, default=False)
+    >>> test_data.add_disk(x0=100, y0=100, r=5, intensity=30)
+    >>> test_data.add_ring_ellipse(x0=100, y0=100, semi_len0=63, semi_len1=70, rotation=45)
+    >>> s = test_data.signal
+    >>> s.set_signal_type("electron_diffraction")
+    >>> import numpy as np
+    >>> mask = np.zeros_like(s.data, dtype=bool)
+    >>> mask[100 - 20:100 + 20, 100 - 20:100 + 20] = True # mask beamstop
+    >>> center, affine = ret.determine_ellipse(s, mask=mask, use_ransac=False)
+    >>> s_corr = s.apply_affine_transformation(affine, inplace=False)
+
+    """
+    pos = _get_max_positions(signal, mask=mask, num_points=num_points)
+    if use_ransac:
+        if guess_starting_params:
+            el, _ = get_ellipse_model_ransac_single_frame(
+                pos,
+                xf=np.mean(pos[:, 0]),
+                yf=np.mean(pos[:, 1]),
+                rf_lim=np.shape(signal.data)[0]/5,
+                semi_len_min=np.std(pos[:, 1]),
+                semi_len_max=np.std(pos[:, 1])*2,
+                semi_len_ratio_lim=1.2,
+                min_samples=6,
+                residual_threshold=20,
+                max_trails=1000
+            )
+        else:
+            el, _ = get_ellipse_model_ransac_single_frame(pos, **kwargs)
+    else:
+        e = EllipseModel()
+        converge = e.estimate(data=pos)
+        el = e
+    if el is not None:
+        affine = _ellipse_to_affine(el.params[3], el.params[2], el.params[4])
+        center = (el.params[0], el.params[1])
+        if return_params:
+            return center, affine, el.params
+        else:
+            return center, affine
+    else:
+        warnings.warn("Ransac Ellipse detection did not converge")
+        return None
